Attribute VB_Name = "mdlMain"
Option Explicit

'Columns IDs:
Public Const COL_FLAG = 1
Public Const COL_READ = 2
Public Const COL_FROM = 3
Public Const COL_SUBJECT = 4
Public Const COL_RECEIVED = 5
Public Const COL_SIZE = 6
Public Const COL_ID = 7
Public Const COL_BODY = 8

'************************************************************************
'************************************************************************
'************************************************************************
'This technic shows you how to use the XP/Vista style without using the
'manifest file. (great!)

'You will have to compile this simpe to see the results.
'************************************************************************
'************************************************************************
'************************************************************************

'Just an explain about the manifest:

'If you want to use XP Visual Styles in a VB application, the fact that the
'Controls don 't draw using the new styles at design- or debug-time can be a
'problem, as your form looks different when once you've compiled. Luckily you
'can persuade both VB5 and VB6 IDEs to use XP Visual Styles too.
'
'The way to do this is to use provide a manifest file telling the OS it
'should link the VB IDE executable to version 6.0 of the ComCtl32.DLL as
'described in Using XP Visual Styles. So for VB6 you add a manifest to the
'path containing VB6.EXE (by default this is C:\Program Files\Microsoft
'Visual Studio\VB98\VB6.EXE) named VB6.EXE.manifest. For VB5 the same thing
'applies except VB's exe is VB5.EXE and the default path is
'C:\ProgramFiles\DevStudio\VB\VB5.EXE). Sample manifest files are provided in
'the downloads. To turn off the new styles again, just shutdown VB, rename
'the manifest file to something else (e.g. add .junk to the end of the
'filename) and restart.
'
'
'Note: this technique was not intended by VB's designers. I've been trying it
'for a while now though: the only problem appears to be that the Palette Tab
'of the any colour picker in the Properties window stops working. Living with
'that isn 't too hard though; you can still type in the colour value in the
'box.
'
'
'Once your application is compiled it will still require its own Manifest and
'to link to ComCtl32.DLL in order to use Visual Styles on XP.
'
'
'When you run a Visual Basic application on an XP machine, you will see that
'although the form gets an XP-style title bar, the controls on the form still
'draw in the old-fashioned Windows style. However, it doesn't take much to
'persuade an application to use the new styles. In some cases, you can get
'existing applications to use the new styles with no additional code
'whatsover!
'
'
'The New XP Styles
'The Windows XP Visual Styles are provided by ComCtl32.dll version 6 or
'later. (In fact, anyone who is as old as me and remembers back to Visual
'Basic 3 may find this familiar, since the exciting 3D control look which was
'provided with Windows 95 was also implemented in the same way). Note that
'unlike previous versions of this DLL, version 6 is not redistributable -
'which sadly means you can only use the visual styles on an operating system
'that has this version installed. At the time of writing this means XP only.
'
'
'ComCtl32 does not apply the latest styles to the client area of an
'application by default. In order to enable it, you need to ensure that your
'application is linked to ComCtl32.dll (by calling the ComCtl
'InitCommonControls API call) and then you need to provide a Manifest which
'specifies that the new version of the control styles should be used.
'
'
'manifests
'Manifests are part of the technologies introduced by Microsoft to attempt to
'resolve the DLL versioning conflicts (normally referred to as DLL hell) so
'common in Windows development. You can read more about these technologies
'and manifests in the Windows XP Technical Article "How To Build and Service
'Isolated Applications and Side-by-Side Assemblies for Windows XP" at MSDN.
'However, for this article all you need to know is that to use version 6 of
'the common controls you need to be able to provide an XML document known as
'a Manifest to ComCtl32.
'
'
'The manifest XML document required to use XP Visual Styles is as follows:
'
'
'<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
'<assembly xmlns="urn:schemas-microsoft-com:asm.v1" manifestVersion="1.0">
'    <assemblyIdentity
'        version = "1.0.0.0"
'        processorArchitecture = "X86"
'        Name = "CompanyName.ProductName.YourAppName"
'        type="win32" />
'    <description>Your application description here</description>
'    <dependency>
'        <dependentAssembly>
'            <assemblyIdentity
'                type="win32"
'                Name = "Microsoft.Windows.Common-Controls"
'                version = "6.0.0.0"
'                processorArchitecture = "X86"
'                publicKeyToken = "6595b64144ccf1df"
'                language="*" />
'        </dependentAssembly>
'    </dependency>
'</assembly>
'Note that the name attribute and the description element are essentially
'free text.
'
'
'Ensuring Your Application Links to ComCtl32.dll
'If you provide a manifest, but your application does not link to
'ComCtl32.dll, then it will fail to load - sometimes with no error message!.
'You need to call at least InitCommonControls before any visual elements are
'displayed. Sometimes, you don't need to do anything because your application
'may already link to ComCtl32.dll (for example, if it includes any of the
'Windows Common Controls provided with Visual Basic), however, to be certain
'it works it is best to call InitCommonControls prior to displaying any
'forms.
'
'
'
'TimeSlot.exe.manifestin the same directory as the executable, TimeSlot.exe
'will automatically get the XP styles. VB5 and VB6 examples are provided. If
'you rename the .manifest file prior to running the app, you can switch off
'the XP styles.
'
'
'A more robust method is to compile the manifest as a resource in your
'application. To do this, the manifest must appear as resource type
'RT_MANIFEST (24) with id CREATEPROCESS_MANIFEST_RESOURCE_ID (1). For some
'bizarre reason, you must also ensure that the resulting XML file is an even
'multiple of 4 bytes long. So for example, if your file is actually 597 bytes
'you need to add padding spaces to make up the file size to 600 bytes before
'compiling. The Resource examples demonstrate how to create this resource
'file using a resource compiler script (.rc file) and RC.exe.
'
'
'Some Notes
'  a.. XP styles do not apply during development time, only at run time. Test
'your executable frequently.
'  b.. Option buttons do not seem to draw correctly when placed on a frame,
'particularly with VB6. You must place your option boxes onto a picture box.
'  c.. 3D borders on PictureBoxes, Images and so on do not draw in the new XP
'style, which is a single line in some combination of the highlight color and
'the form background. To draw these new borders, check out the article
'Drawing with the XP Visual Styles
'
'************************************************************************
'************************************************************************
'************************************************************************
'This technic shows you how to use the XP/Vista style without using the
'manifest file. (great!)

'You will have to compile this simpe to see the results.
'************************************************************************
'************************************************************************
'************************************************************************

'Add those declares to any one of your projects:

Private Type tagInitCommonControlsEx
   lngSize As Long
   lngICC As Long
End Type
Private Declare Function InitCommonControlsEx Lib "COMCTL32.DLL" (iccex As tagInitCommonControlsEx) As Boolean
Private Declare Function SetErrorMode Lib "kernel32" (ByVal wMode As Long) As Long

Private Const SEM_FAILCRITICALERRORS = &H1
Private Const SEM_NOGPFAULTERRORBOX = &H2
Private Const SEM_NOOPENFILEERRORBOX = &H8000

Private Const ICC_USEREX_CLASSES = &H200

Private m_bInIDE As Boolean

Public Sub Main()

   Dim iccex As tagInitCommonControlsEx
   With iccex
       .lngSize = LenB(iccex)
       .lngICC = ICC_USEREX_CLASSES
   End With
   
   InitCommonControlsEx iccex
   
   On Error GoTo 0
   
   Load frmMain
   frmMain.Show

End Sub

Public Sub UnloadApp()
   If Not InIDE() Then
      SetErrorMode SEM_NOGPFAULTERRORBOX
   End If
End Sub

Public Property Get InIDE() As Boolean
   Debug.Assert (IsInIDE())
   InIDE = m_bInIDE
End Property

Private Function IsInIDE() As Boolean
   m_bInIDE = True
   IsInIDE = m_bInIDE
End Function


